@@ -1,18 +1,21 @@
 #' @title Converts a time value given as number of seconds since midnight to the
 #'   H:M:S format
-#' @description This function is very similar to \code{strftime} with the
+#' @description This function is very similar to `strftime` with the
 #'   \code{\%X} conversion specification. Hour values larger than 24 are
 #'   permitted. Fractions will be rounded down to the next integer. Non-numeric
-#'   values are coerced to \code{NA} with a warning.
+#'   values are coerced to `NA` with a warning.
 #' @param x A (vector of) numbers.
-#' @return A (vector of) character values of the same length as \code{x}.
-#' @seealso \link[base]{strftime}
+#' @return A (vector of) character values of the same length as `x`.
+#' @seealso [base::strftime()]
 #' @examples
 #' seconds.to.hms(c(1, 60, 3600.5))
 #' seconds.to.hms(c(100000, -4000.5))
 #' seconds.to.hms("invalid")
 #' @export
+#' @family deprecated functions
+#' @name seconds.to.hms-deprecated
 seconds.to.hms <- function(x) {
+  deprecate("hms::as.character()")
   if (!is.integer(x))
     x <- as.integer(floor(as.numeric(x)))
 
